@@ -9,7 +9,7 @@
  *	 IBM Corporation - initial API and implementation
  *******************************************************************************/
 /*eslint-env node */
-var api = require('../api'), writeError = api.writeError;
+var api = require('../api'), writeError = api.writeError, writeResponse = api.writeResponse;
 var args = require('../args');
 var async = require('async');
 var git = require('nodegit');
@@ -25,21 +25,22 @@ module.exports = {};
 
 module.exports.router = function(options) {
 	var fileRoot = options.fileRoot;
-	if (!fileRoot) { throw new Error('options.root is required'); }
-	var contextPath = options.options.configParams["orion.context.path"] || "";
+	var gitRoot = options.gitRoot;
+	if (!fileRoot) { throw new Error('options.fileRoot is required'); }
+	if (!gitRoot) { throw new Error('options.gitRoot is required'); }
 	
 	module.exports.remoteBranchJSON = remoteBranchJSON;
 	module.exports.remoteJSON = remoteJSON;
 
 	return express.Router()
 	.use(bodyParser.json())
-	.get(contextPath + '/file*', getRemotes)
-	.get('/:remoteName'+ contextPath + '/file*', getRemotes)
-	.get('/:remoteName/:branchName'+ contextPath + '/file*', getRemotes)
-	.delete('/:remoteName'+ contextPath + '/file*', deleteRemote)
-	.post(contextPath + '/file*', addRemote)
-	.post('/:remoteName'+ contextPath + '/file*', postRemote)
-	.post('/:remoteName/:branchName'+ contextPath + '/file*', postRemote);
+	.get(fileRoot + '*', getRemotes)
+	.get('/:remoteName'+ fileRoot + '*', getRemotes)
+	.get('/:remoteName/:branchName'+ fileRoot + '*', getRemotes)
+	.delete('/:remoteName'+ fileRoot + '*', deleteRemote)
+	.post(fileRoot + '*', addRemote)
+	.post('/:remoteName'+ fileRoot + '*', postRemote)
+	.post('/:remoteName/:branchName'+ fileRoot + '*', postRemote);
 	
 function remoteBranchJSON(remoteBranch, commit, remote, fileDir, branch){
 	var fullName, shortName, remoteURL;
@@ -54,17 +55,17 @@ function remoteBranchJSON(remoteBranch, commit, remote, fileDir, branch){
 		remoteURL = api.join(util.encodeURIComponent(remote.name()), util.encodeURIComponent(branch.Name));
 	}
 	return {
-		"CloneLocation": contextPath + "/gitapi/clone" + fileDir,
-		"CommitLocation": contextPath + "/gitapi/commit/" + util.encodeURIComponent(fullName) + fileDir,
-		"DiffLocation": contextPath + "/gitapi/diff/" + util.encodeURIComponent(shortName) + fileDir,
+		"CloneLocation": gitRoot + "/clone" + fileDir,
+		"CommitLocation": gitRoot + "/commit/" + util.encodeURIComponent(fullName) + fileDir,
+		"DiffLocation": gitRoot + "/diff/" + util.encodeURIComponent(shortName) + fileDir,
 		"FullName": fullName,
 		"GitUrl": remote.url(),
-		"HeadLocation": contextPath + "/gitapi/commit/HEAD" + fileDir,
+		"HeadLocation": gitRoot + "/commit/HEAD" + fileDir,
 		"Id": remoteBranch && commit ? commit.sha() : undefined,
-		"IndexLocation": contextPath + "/gitapi/index" + fileDir,
-		"Location": contextPath + "/gitapi/remote/" + remoteURL + fileDir,
+		"IndexLocation": gitRoot + "/index" + fileDir,
+		"Location": gitRoot + "/remote/" + remoteURL + fileDir,
 		"Name": shortName,
-		"TreeLocation": contextPath + "/gitapi/tree" + fileDir + "/" + util.encodeURIComponent(shortName),
+		"TreeLocation": gitRoot + "/tree" + fileDir + "/" + util.encodeURIComponent(shortName),
 		"Type": "RemoteTrackingBranch"
 	};
 }
@@ -72,11 +73,11 @@ function remoteBranchJSON(remoteBranch, commit, remote, fileDir, branch){
 function remoteJSON(remote, fileDir, branches) {
 	var name = remote.name();
 	return {
-		"CloneLocation": contextPath + "/gitapi/clone" + fileDir,
+		"CloneLocation": gitRoot + "/clone" + fileDir,
 		"IsGerrit": false, // should check 
 		"GitUrl": remote.url(),
 		"Name": name,
-		"Location": contextPath + "/gitapi/remote/" + util.encodeURIComponent(name) + fileDir,
+		"Location": gitRoot + "/remote/" + util.encodeURIComponent(name) + fileDir,
 		"Type": "Remote",
 		"Children": branches
 	};
@@ -106,10 +107,10 @@ function getRemotes(req, res) {
 					cb();
 				});
 			}, function() {
-				res.status(200).json({
+				writeResponse(200, res, null, {
 					"Children": r,
 					"Type": "Remote"
-				});
+				}, true);
 			});
 		});
 	}
@@ -151,7 +152,7 @@ function getRemotes(req, res) {
 					if (err) {
 						return writeError(403, res);
 					}
-					res.status(200).json(remoteJSON(theRemote, fileDir, branches));
+					writeResponse(200, res, null, remoteJSON(theRemote, fileDir, branches), true);
 				});
 			});
 		});
@@ -174,7 +175,7 @@ function getRemotes(req, res) {
 			return theRepo.getBranchCommit(branch);
 		})
 		.then(function(commit) {
-			res.status(200).json(remoteBranchJSON(theBranch, commit, theRemote, fileDir));
+			writeResponse(200, res, null, remoteBranchJSON(theBranch, commit, theRemote, fileDir), true);
 		})
 		.catch(function() {
 			return writeError(403, res);
@@ -200,9 +201,9 @@ function addRemote(req, res) {
 		var remoteName = remote ? remote.name() : req.body.Remote;
 		var configFile = api.join(repo.path(), "config");
 		function done () {
-			res.status(201).json({
-				"Location": contextPath + "/gitapi/remote/" + util.encodeURIComponent(remoteName) + fileDir
-			});
+			writeResponse(201, res, null, {
+				"Location": gitRoot + "/remote/" + util.encodeURIComponent(remoteName) + fileDir
+			}, true);
 		}
 		args.readConfigFile(configFile, function(err, config) {
 			if (err) {
@@ -277,7 +278,7 @@ function fetchRemote(req, res, remote, branch, force) {
 		return remoteObj.fetch(
 			refSpec ? [refSpec] : null,
 			{
-				callbacks: clone.getRemoteCallbacks(req.body, task),
+				callbacks: clone.getRemoteCallbacks(req, task),
 				downloadTags: 3     // 3 = C.GIT_REMOTE_DOWNLOAD_TAGS_ALL (libgit2 const) 
 			},
 			"fetch"	
@@ -331,7 +332,7 @@ function pushRemote(req, res, remote, branch, pushSrcRef, tags, force) {
 			});
 		}
 		return remoteObj.push(
-			refSpecs, {callbacks: clone.getRemoteCallbacks(req.body, task)}
+			refSpecs, {callbacks: clone.getRemoteCallbacks(req, task)}
 		);
 	})
 	.then(function(err) {
